@@ -460,7 +460,7 @@ def create_postgres_user(config):
     retry = 0
     while retry < 4:
         res = exec_cmd(config['postgres_container'], cmd, 'postgres')
-        if 'could not connect to server' in res:
+        if 'could not connect to server' in res or 'connection to server on socket' in res:
             retry += 1
             _logger.info('Waiting for the postgres container to start (retrying %s)', retry)
             time.sleep(3)
@@ -566,29 +566,18 @@ def test_module(config):
     # subprocess.call(['docker', 'cp', config.get('container_name')+':/tmp/overage', cover_data])
 
     cover_reports = [
-        'coverage report -m --show-missing'.format(workdir=config.get('coverage_reports')),
-        'coverage html -d {workdir}'.format(workdir=config.get('coverage_reports')),
-        'coverage xml -o {workdir}/coverage.xml'.format(workdir=config.get('coverage_reports')),
+        'coverage report -m --show-missing',
+        'coverage html -d {coverage_reports}/htmlcov'.format(**config),
+        'coverage xml -o {coverage_reports}/coverage.xml'.format(**config),
     ]
 
-    cwd = getcwd()
-    chdir(config.get('container_vol'))
     for cr in cover_reports:
         _logger.info('Running command: %s', cr)
         cmd_res = exec_cmd(config['container_name'], cr, 'odoo', stream=False, workdir=config.get('coverage_home'))
         _logger.info('Command: "%s" exited with:\n%s', cr, cmd_res)
 
-    reports_getters =[
-        'docker cp {container}:{reports} .'.format(container=config.get('container_name'), reports=config.get('coverage_reports')),
-        'rm .coveragerc',
-    ]
-
-    reports_dir = path.basename(config.get('coverage_reports'))
-    for rg in reports_getters:
-        subprocess.call(shlex.split(rg))
-    copy_files(reports_dir, './')
-    rmtree(reports_dir)
-    chdir(cwd)
+    cmd = 'docker cp {container_name}:{coverage_reports}/. {container_vol}/.'.format(**config)
+    subprocess.call(shlex.split(cmd))
 
 
     return test_log[0]
